<?php 

/* Disallow direct access */
if ( ! defined( 'ABSPATH' ) ) exit;

class V12_Customizer {

    public static function register( $wp_customize ) {
        
        $defaults = v12_defaults();
        
        // Load sinitize functions
        require_once( V12_CUSTOMIZER_DIR . '/sanitize.php' );
        
        // Load custom controls
        require_once( V12_CUSTOMIZER_DIR . '/controls/info.php' );
        
        // Defaults reorganization
        
        
        // Load Panels
        
            // About
            $wp_customize->add_section( 'about', array(
                'title' => __( 'About V12 Theme', 'v12' ), 'priority' => 1
            ) );
            require( V12_CUSTOMIZER_DIR . '/sections/about.php' );
            
            // Site Identity
            $wp_customize->get_section( 'title_tagline' )->priority = 10;
            $wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
        
            // Header
            $wp_customize->add_section( 'header', array(
                'title' => __( 'Header', 'v12' ), 'priority' => 20,
            ) );
            require( V12_CUSTOMIZER_DIR . '/sections/header.php' );
            
            // Front Page
            $wp_customize->add_section( 'frontpage', array(
                'title' => __( 'Front Page', 'v12' ), 'priority' => 30
            ) );
            require( V12_CUSTOMIZER_DIR . '/sections/frontpage.php' );
            
            // Blog
            $wp_customize->add_section( 'blog', array(
                'title' => __( 'Blog', 'v12' ), 'priority' => 40,
                'description' => __( 'Options for your latest blog posts homepage', 'v12' )
            ) );
            require( V12_CUSTOMIZER_DIR . '/sections/blog.php' );
            
            // Single Posts
            $wp_customize->add_section( 'single', array(
                'title' => __( 'Single Posts', 'v12' ), 'priority' => 50,
                'description' => __( 'Options for single posts', 'v12' )
            ) );
            require( V12_CUSTOMIZER_DIR . '/sections/single.php' );
            
            // Layout -> Pages
            $wp_customize->add_section( 'pages', array(
                'title' => __( 'Pages', 'v12' ), 'priority' => 60,
                'description' => __( 'Options for standard pages', 'v12' )
            ) );
            require( V12_CUSTOMIZER_DIR . '/sections/pages.php' );
            
            // Layout -> Archives
            $wp_customize->add_section( 'archives', array(
                'title' => __( 'Archives', 'v12' ), 'priority' => 70,
                'description' => __( 'Options for archives, categories, tags and any other WP generated pages', 'v12' )
            ) );
            require( V12_CUSTOMIZER_DIR . '/sections/archives.php' );
            
            // Layout -> Footer
            $wp_customize->add_section( 'footer', array(
                'title' => __( 'Footer', 'v12' ), 'priority' => 80
            ) );
            require( V12_CUSTOMIZER_DIR . '/sections/footer.php' );
        
            // Colors (The section is enabled via add theme support)
            $wp_customize->get_section( 'colors' )->priority = 90;
            require( V12_CUSTOMIZER_DIR . '/sections/colors.php' );
    }
    
    public static function enqueue_live_scripts() {
        wp_enqueue_script(  'v12-customizer-live', V12_CUSTOMIZER_URI . '/assets/v12-customizer-live.js', array( 'jquery','customize-preview' ), '', true );
    }
    
    public static function header_output() { ?>
        
        <!--Customizer CSS--> 
        <style type="text/css">
            <?php 
                self::generate_css('#main', 'margin-top', 'header_spacing', '', 'px'); 
                self::generate_css('#main', 'margin-top', 'header_spacing_mobile', '', 'px', '@media (max-width: 768px){ ', ' }');
                self::generate_css('a, a:hover, .widget ul a:hover, #footer a, .comments-area a', 'color', 'colors_accent');
                self::generate_css('.post .read-more, .back-to-top:hover, .comment-form input[type="submit"]', 'background', 'colors_accent');
                self::generate_css('.widget .widget-title, .post .sticky-post', 'border-bottom-color', 'colors_accent');
                self::generate_css('.site-logo a', 'color', 'colors_site_title');
                self::generate_css('body', 'background-color', 'background_color');
            ?> 
        </style> 
        <!--/Customizer CSS-->
    <?php }
   
   public static function generate_css( $selector, $style, $mod_name, $prefix='', $postfix='', $wrap_before = '', $wrap_after ='', $echo=true ) {
      $return = '';
      $mod = get_theme_mod($mod_name);
      if ( ! empty( $mod ) ) {
         $return = sprintf('%s%s { %s:%s; }%s',
            $wrap_before,
            $selector,
            $style,
            $prefix.$mod.$postfix,
            $wrap_after
         );
         if ( $echo ) {
            echo strip_tags( $return . ' ' );
         }
      }
      return $return;
    }
}
    
add_action( 'customize_register', array( 'V12_Customizer', 'register' ) );
add_action( 'customize_preview_init', array( 'V12_Customizer', 'enqueue_live_scripts' ) );
add_action( 'wp_head' , array( 'V12_Customizer' , 'header_output' ) );