<?php 

/* Disallow direct access */
if ( ! defined( 'ABSPATH' ) ) exit;

class V12_Setup {

    public function __construct() {
        add_action( 'after_setup_theme', array( $this, 'setup' ) );
        add_action( 'wp_enqueue_scripts', array( $this, 'styles_scripts' ) );
        add_action( 'widgets_init', array( $this, 'sidebars' ) );
        add_action( 'wp_head', array( $this, 'pingback' ) );
    }
    
    public function setup() {
        /* Feed link support */
        add_theme_support('automatic-feed-links');

        /* Post Thumbnails */
        add_theme_support('post-thumbnails');

        /* Custom Background */   
        add_theme_support( 'custom-background' );
        
        // Add title tag support
        add_theme_support( 'title-tag' );

        // Add translation support
        load_theme_textdomain( 'v12');

        // Custom logo
        add_theme_support( 'custom-logo', array(
            'height'      => 40,
            'flex-width' => true
        ));

        // Register main menu
        register_nav_menu( 'primary', __('Primary Menu', 'v12') );

        // Add image size for the main featured iamge
        add_image_size('v12_848', 848, 9999, false);

        /* Content width */
        global $content_width;
        if ( ! isset( $content_width ) ) {
        	$content_width = 848;
        }
    }
    
    public function styles_scripts() {
        $get_theme = wp_get_theme();
        
        // Styles
        wp_enqueue_style('v12_google_font', 'https://fonts.googleapis.com/css?family=Raleway:400,700', false, $get_theme['Version'], 'screen');
        wp_enqueue_style('bootstrap', V12_ASSETS_URI . '/css/bootstrap.min.css', array('v12_google_font'), $get_theme['Version'], 'screen');
        wp_enqueue_style('font-awesome',  V12_ASSETS_URI . '/css/font-awesome.min.css');
        wp_enqueue_style('v12-style', get_stylesheet_uri(), array('bootstrap'), $get_theme['Version'], 'screen');
        
        // JS
        wp_enqueue_script( 'hoverIntent' );
        wp_enqueue_script( 'superfish', V12_ASSETS_URI . '/js/superfish.min.js', array('jquery'), $get_theme['Version'], true );
        wp_enqueue_script( 'v12-custom', V12_ASSETS_URI . '/js/custom.js', array('jquery'), $get_theme['Version'], true );
        
        /* Comment form js */
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
            wp_enqueue_script( 'comment-reply' );
        }
    }
    
    public function sidebars() {
        
        register_sidebar( array(
            'name' => __('Sidebar', 'v12'),
            'id' => 'sidebar',
            'description' => __('This is a regular widgetized sidebar', 'v12'),
            'before_widget' => '<section class="widget">',
            'after_widget' => '</section>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>'
        ) );
        
        if( v12_option('widgets', 'footer') >= 1) {
            register_sidebar( array(
                'name' => __('Footer Column 1', 'v12'),
                'id' => 'footer-1',
                'before_widget' => '<section class="widget">',
                'after_widget' => '</section>',
                'before_title' => '<h3 class="widget-title">',
                'after_title' => '</h3>'
            ) );
        }
        
        if( v12_option('widgets', 'footer') >= 2) {
            register_sidebar( array(
                'name' => __('Footer Column 2', 'v12'),
                'id' => 'footer-2',
                'before_widget' => '<section class="widget">',
                'after_widget' => '</section>',
                'before_title' => '<h3 class="widget-title">',
                'after_title' => '</h3>'
            ) );
        }
        
        if( v12_option('widgets', 'footer') >= 3) {
            register_sidebar( array(
                'name' => __('Footer Column 3', 'v12'),
                'id' => 'footer-3',
                'before_widget' => '<section class="widget">',
                'after_widget' => '</section>',
                'before_title' => '<h3 class="widget-title">',
                'after_title' => '</h3>'
            ) );
        }
        
        if( v12_option('widgets', 'footer') == 4) {
            register_sidebar( array(
                'name' => __('Footer Column 4', 'v12'),
                'id' => 'footer-4',
                'before_widget' => '<section class="widget">',
                'after_widget' => '</section>',
                'before_title' => '<h3 class="widget-title">',
                'after_title' => '</h3>'
            ) );
        }
    }
    
    public function pingback() {
        if ( is_singular() && pings_open() ) {
            printf( '<link rel="pingback" href="%s">' . "\n", get_bloginfo( 'pingback_url' ) );
        }
    }
}

new V12_Setup;